#ifndef NT2_INCLUDE_FUNCTIONS_PLUS_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_PLUS_HPP_INCLUDED

#include <nt2/operator/include/functions/plus.hpp>

#endif
